* {
    color: var(--bs-body-color);
    text-decoration: unset !important;
}

body {
    display: flex;
    flex-direction: column;
    min-height: 100vh;
}

/* Header */
[data-bs-theme="light"] .bg-header {
    background-color: #256CBA;
}

[data-bs-theme="dark"] .bg-header {
    background-color: #402565;
}

.border-header {
    border-radius: var(--bs-border-radius-xl);
}

.logo {
    background-image: url('../images/logo.svg');
    height: 56px;
    width: 199px;
}

/* Sidebar */
.btn-link, .btn-link-single {
    display: flex;
    flex-direction: row;
    background-color: rgb(var(--bs-secondary-bg-rgb), 0.55);
    border-color: var(--bs-border-color);
    border-radius: var(--bs-border-radius-xl);
    border-style: var(--bs-border-style);
    border-width: var(--bs-border-width);
    font-weight: 600;
    padding: 0.75rem;
    text-decoration: none;
    width: 100%;
}

.btn-link:hover, .btn-link-single:hover, .btn-link-single:focus {
    background-color: rgb(var(--bs-secondary-bg-rgb), 0.55);
    border-color: var(--bs-border-color);
    border-radius: var(--bs-border-radius-xl);
    border-style: var(--bs-border-style);
    border-width: var(--bs-border-width);
}

.btn-link-text {
    display: flex;
    flex-grow: 1;
}

.btn-link:after {
    color: var(--bs-body-color);
    content: "\F285";
    font-family: "bootstrap-icons";
    transition: transform .35s ease;
    transform-origin: .5em 50%;
}

.btn-link[aria-expanded=true]:after {
    transform: rotate(90deg);
}

.btn-link[aria-expanded=true] {
    border-bottom-left-radius: unset !important;
    border-bottom-right-radius: unset !important;
    border-bottom-width: 0 !important;
}

.sidebar-expanded {
    background-color: rgb(var(--bs-secondary-bg-rgb), 0.55) !important;
    border-color: var(--bs-border-color) !important;
    border-bottom-left-radius: var(--bs-border-radius-xl) !important;
    border-bottom-right-radius: var(--bs-border-radius-xl) !important;
    border-style: var(--bs-border-style) !important;
    border-width: var(--bs-border-width) !important;
    padding: 0 0.75rem 0.75rem;
    list-style: none;
}

.btn-link[aria-expanded=true] + div .sidebar-expanded {
    border-top-width: 0 !important;
}

.no-transition {
    transition: none !important;
    animation: none !important;
}

/* Content */
.bg-content {
    background-color: rgb(var(--bs-secondary-bg-rgb), 0.55);
}

/* Headings */
h1 {
    background-color: rgb(var(--bs-secondary-bg-rgb), 1.0);
    border-width: var(--bs-border-width);
    border-color: var(--bs-border-color);
    border-style: var(--bs-border-style);
    border-radius: var(--bs-border-radius-xl);
    font-size: 1.5rem;
    font-weight: bolder;
    padding: 1rem;
    text-align: left;
}

h2 {
    font-size: 1.35rem;
    font-weight: bold;
    text-align: left;
}

h3 {
    font-size: 1.25rem;
    font-weight: lighter;
    text-align: left;
}

h4 {
    font-size: 1.15rem;
    font-weight: bold;
    text-align: left;
}

/* Lecture Object */
.lecture-slides {
    aspect-ratio: 16 / 9;
    border-radius: var(--bs-border-radius-xl);
    display: block;
    height: 720px;
    margin: 0.75rem auto 1rem auto;
    width: 1280px;
}

/* Tabs */
.tabbed-set {
    position: relative;
    display: flex;
    flex-wrap: wrap;
    border-radius: 0.1rem;
}

.tabbed-set > input {
    display: none;
}

.tabbed-set label {
    width: auto;
    border-radius: var(--bs-border-radius-xl);
    padding: 0.65rem 1.25rem;
    font-weight: 550;
    font-size: 1rem;
    white-space: nowrap;
    border-width: var(--bs-border-width);
    border-color: var(--bs-border-color);
    border-style: var(--bs-border-style);
    /*border-bottom: 0.15rem solid transparent;*/
    /*border-top-left-radius: 0.1rem;*/
    /*border-top-right-radius: 0.1rem;*/
    cursor: pointer;
    margin-right: 0.5rem;
    transition: background-color 250ms, color 250ms;
}

.tabbed-set .tabbed-content {
    width: 100%;
    display: none;
    padding-top: 0.75rem;
}

.tabbed-set input {
    position: absolute;
    opacity: 0;
}

.tabbed-set input:checked:nth-child(n+1) + label {
    background: rgba(var(--bs-body-color-rgb), 0.03);
    border-color: var(--bs-border-color-translucent);
}

@media screen {
    .tabbed-set input:nth-child(n+1):checked + label + .tabbed-content {
        order: 99;
        display: block;
    }
}

@media print {
    .tabbed-content {
        display: contents;
    }
}

/* Tables */
div.table {
    display: flex;
    background-color: rgb(var(--bs-secondary-bg-rgb), 0.55);
    border-width: var(--bs-border-width);
    border-color: var(--bs-border-color);
    border-style: var(--bs-border-style);
    border-radius: var(--bs-border-radius-lg) !important;
    margin: 0 auto 0.75rem auto;
    width: 75%;
}

div.table:before {
    background-color: rgb(var(--bs-secondary-bg-rgb), 1.0);
    border-right-width: var(--bs-border-width);
    border-right-color: var(--bs-border-color);
    border-right-style: var(--bs-border-style);
    border-bottom-left-radius: var(--bs-border-radius-lg) !important;
    border-top-left-radius: var(--bs-border-radius-lg) !important;
    content: "\F5AA";
    font-family: "bootstrap-icons";
    padding: 0.75rem;
    width: 2.5rem;
}

table {
    margin: 0.75rem;
    table-layout: fixed;
    width: 100%;
}

thead th {
    background-color: rgb(var(--bs-secondary-bg-rgb), 1.0) !important;
}

th, td, tr {
    background: none !important;
    border-color: var(--bs-border-color) !important;
    padding: 0.5rem;
}

/* Footer */
footer {
    background-color: rgb(var(--bs-secondary-bg-rgb), 0.55);
    border-color: var(--bs-border-color);
    border-radius: var(--bs-border-radius-xl);
    border-style: var(--bs-border-style);
    border-width: var(--bs-border-width);
    flex: 0 0;
    margin: auto 1rem 1rem;
    padding: 0.75rem;
    text-align: center;
}

/* Images */
img {
    border-radius: var(--bs-border-radius-xl);
    display: block;
    margin: 0 auto 0 auto;
}

/* Admonition */
summary::marker {
    display: none;
    content: "";
}

/* Lab Activity Styling */
details.activity {
    background-color: rgb(var(--bs-secondary-bg-rgb), 0.55);
    border-color: var(--bs-border-color);
    border-radius: var(--bs-border-radius-xl);
    border-style: var(--bs-border-style);
    border-width: var(--bs-border-width);
    margin-bottom: 1rem;
    padding: 0.75rem;
}

details.activity:last-of-type {
    margin-bottom: 0;
}

details.activity[open] > summary {
    margin-bottom: 0.75rem;
}

details.activity > summary {
    color: rgb(var(--bs-body-color-rgb));
    font-size: 1.35rem;
    font-weight: bold;
    margin-bottom: 0;
    text-align: left;
}

details.activity summary strong {
    font-weight: 600;
    margin-right: 0.5rem;
}

/* Source Code */
pre[class*=language], pre[class=highlight], div.highlight {
    display: flex;
    font-family: Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace !important;
    margin: 0 auto 0.75rem auto;
    width: 75%;
}

pre[class*=language]:before, pre[class=highlight]:before, div.highlight:before {
    background-color: rgb(var(--bs-secondary-bg-rgb), 1.0);
    border-right-width: var(--bs-border-width);
    border-right-color: var(--bs-border-color);
    border-right-style: var(--bs-border-style);
    border-bottom-left-radius: var(--bs-border-radius-lg) !important;
    border-top-left-radius: var(--bs-border-radius-lg) !important;
    content: "\F2C6";
    font-family: "bootstrap-icons";
    padding: 0.75rem;
    width: 2.5rem;
}

pre[class*=language], pre[class=highlight], div.highlight {
    background-color: rgb(var(--bs-secondary-bg-rgb), 0.55);
    border-width: var(--bs-border-width);
    border-color: var(--bs-border-color);
    border-style: var(--bs-border-style);
    border-radius: var(--bs-border-radius-lg) !important;
}

pre[class*=language] code, pre[class=highlight] code, div.highlight code {
    background: unset;
    border: unset !important;
    border-radius: unset !important;
    font-family: Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace !important;
    margin: 0;
    max-height: 50vh;
    line-height: 1.25rem;
    text-align: left;
    text-wrap: wrap;
    width: 100%;
}

/* Code Highlighting */
pre code.hljs {
    display: block;
    overflow-x: auto;
    padding: 1em
}

code.hljs {
    padding: 3px 5px
}

[data-bs-theme="light"] .hljs {
    color: #383a42;
}

[data-bs-theme="light"] .hljs-comment,
[data-bs-theme="light"] .hljs-quote {
    color: #a0a1a7;
    font-style: italic;
}

[data-bs-theme="light"] .hljs-doctag,
[data-bs-theme="light"] .hljs-keyword,
[data-bs-theme="light"] .hljs-formula {
    color: #a626a4;
}

[data-bs-theme="light"] .hljs-section,
[data-bs-theme="light"] .hljs-name,
[data-bs-theme="light"] .hljs-selector-tag,
[data-bs-theme="light"] .hljs-deletion,
[data-bs-theme="light"] .hljs-subst {
    color: #e45649;
}

[data-bs-theme="light"] .hljs-literal {
    color: #0184bb;
}

[data-bs-theme="light"] .hljs-string,
[data-bs-theme="light"] .hljs-regexp,
[data-bs-theme="light"] .hljs-addition,
[data-bs-theme="light"] .hljs-attribute,
[data-bs-theme="light"] .hljs-meta .hljs-string {
    color: #50a14f;
}

[data-bs-theme="light"] .hljs-attr,
[data-bs-theme="light"] .hljs-variable,
[data-bs-theme="light"] .hljs-template-variable,
[data-bs-theme="light"] .hljs-type,
[data-bs-theme="light"] .hljs-selector-class,
[data-bs-theme="light"] .hljs-selector-attr,
[data-bs-theme="light"] .hljs-selector-pseudo,
[data-bs-theme="light"] .hljs-number {
    color: #986801;
}

[data-bs-theme="light"] .hljs-symbol,
[data-bs-theme="light"] .hljs-bullet,
[data-bs-theme="light"] .hljs-link,
[data-bs-theme="light"] .hljs-meta,
[data-bs-theme="light"] .hljs-selector-id,
[data-bs-theme="light"] .hljs-title {
    color: #4078f2;
}

[data-bs-theme="light"] .hljs-built_in,
[data-bs-theme="light"] .hljs-title.class_,
[data-bs-theme="light"] .hljs-class .hljs-title {
    color: #c18401;
}

[data-bs-theme="dark"] .hljs {
    color: #abb2bf;
}

[data-bs-theme="dark"] .hljs-comment,
[data-bs-theme="dark"] .hljs-quote {
    color: #5c6370;
    font-style: italic;
}

[data-bs-theme="dark"] .hljs-doctag,
[data-bs-theme="dark"] .hljs-keyword,
[data-bs-theme="dark"] .hljs-formula {
    color: #c678dd;
}

[data-bs-theme="dark"] .hljs-section,
[data-bs-theme="dark"] .hljs-name,
[data-bs-theme="dark"] .hljs-selector-tag,
[data-bs-theme="dark"] .hljs-deletion,
[data-bs-theme="dark"] .hljs-subst {
    color: #e06c75;
}

[data-bs-theme="dark"] .hljs-literal {
    color: #56b6c2;
}

[data-bs-theme="dark"] .hljs-string,
[data-bs-theme="dark"] .hljs-regexp,
[data-bs-theme="dark"] .hljs-addition,
[data-bs-theme="dark"] .hljs-attribute,
[data-bs-theme="dark"] .hljs-meta .hljs-string {
    color: #98c379;
}

[data-bs-theme="dark"] .hljs-attr,
[data-bs-theme="dark"] .hljs-variable,
[data-bs-theme="dark"] .hljs-template-variable,
[data-bs-theme="dark"] .hljs-type,
[data-bs-theme="dark"] .hljs-selector-class,
[data-bs-theme="dark"] .hljs-selector-attr,
[data-bs-theme="dark"] .hljs-selector-pseudo,
[data-bs-theme="dark"] .hljs-number {
    color: #d19a66;
}

[data-bs-theme="dark"] .hljs-symbol,
[data-bs-theme="dark"] .hljs-bullet,
[data-bs-theme="dark"] .hljs-link,
[data-bs-theme="dark"] .hljs-meta,
[data-bs-theme="dark"] .hljs-selector-id,
[data-bs-theme="dark"] .hljs-title {
    color: #61aeee;
}

[data-bs-theme="dark"] .hljs-built_in,
[data-bs-theme="dark"] .hljs-title.class_,
[data-bs-theme="dark"] .hljs-class .hljs-title {
    color: #e6c07b;
}

.hljs-emphasis {
    font-style: italic;
}

.hljs-strong {
    font-weight: bold;
}

.hljs-link {
    text-decoration: underline;
}

/* Link Boxes */
p a.link-box {
    background-color: var(--bs-primary-bg-subtle);
    border-color: var(--bs-primary-border-subtle);
    border-radius: var(--bs-border-radius-lg);
    border-style: var(--bs-border-style);
    border-width: var(--bs-border-width);
    color: var(--bs-primary-text-emphasis);
    display: block;
    margin: 0 auto 0 auto;
    padding: 0.75rem;
    text-align: center;
    width: 75%;
}

p a.glightbox {
    background-color: unset;
    border-color: unset;
    border-radius: unset;
    border-style: unset;
    border-width: unset;
}

/* Diagrams */
.current {
    border-color: var(--bs-primary-border-subtle) !important;
    background-color: var(--bs-primary-bg-subtle) !important;
    stroke: var(--bs-primary-border-subtle) !important;
    fill: var(--bs-primary-bg-subtle) !important;
}

.current-text {
    fill: var(--bs-primary-text-emphasis) !important;

}

.target {
    border-color: var(--bs-danger-border-subtle) !important;
    background-color: var(--bs-danger-bg-subtle) !important;
    stroke: var(--bs-danger-border-subtle) !important;
    fill: var(--bs-danger-bg-subtle) !important;
}

.target-text {
    color: var(--bs-danger-text-emphasis) !important;
    fill: var(--bs-danger-text-emphasis) !important;
}

.previous {
    border-color: var(--bs-warning-border-subtle) !important;
    background-color: var(--bs-warning-bg-subtle) !important;
    stroke: var(--bs-warning-border-subtle) !important;
    fill: var(--bs-warning-bg-subtle) !important;
}

.previous-text {
    fill: var(--bs-warning-text-emphasis) !important;
}

/* Mermaid */

.mermaid svg {
    display: block;
    margin: 0 auto 0 auto;
}

.line {
    stroke: var(--bs-border-color) !important;
}

span.nodeLabel, .label text {
    color: rgba(var(--bs-body-color-rgb), 0.77) !important;
    fill: rgba(var(--bs-body-color-rgb), 0.77) !important;
}

.edgeLabel .label span {
    background: rgba(var(--bs-body-color-rgb), 0.03) !important;
    color: rgba(var(--bs-body-color-rgb), 0.77) !important;
    font-variant: all-small-caps;
}

.node rect, polygon, circle {
    fill: rgba(var(--bs-body-color-rgb), 0.03) !important;
    stroke: var(--bs-border-color) !important;
}

.flowchart-link, .relation, .divider {
    stroke: var(--bs-border-color) !important;
}

.marker {
    fill: var(--bs-border-color) !important;
    stroke: var(--bs-border-color) !important;
}

path {
    fill: var(--bs-border-color) !important;
    stroke: var(--bs-border-color) !important;
}

path[marker-start] {
    fill: none !important;
}

.classTitle {
    text-transform: uppercase;
}

.clusters rect {
    fill: rgba(var(--bs-body-color-rgb), 0.015) !important;
    stroke: var(--bs-border-color) !important;
}

.label0, .commit0 {
    border-color: rgba(var(--bs-primary-rgb), 0.25) !important;
    background-color: rgba(var(--bs-primary-rgb), 0.25) !important;
    stroke: rgba(var(--bs-primary-rgb), 0.25) !important;
    fill: rgba(var(--bs-primary-rgb), 0.25) !important;
}

.label1, .commit1 {
    border-color: rgba(var(--bs-warning-rgb), 0.25) !important;
    background-color: rgba(var(--bs-warning-rgb), 0.25) !important;
    stroke: rgba(var(--bs-warning-rgb), 0.25) !important;
    fill: rgba(var(--bs-warning-rgb), 0.25) !important;
}

.commit-label-bkg {
    fill: rgba(var(--bs-body-color-rgb), 0.03) !important;
}

.commit-label {
    fill: rgba(var(--bs-body-color-rgb), 0.77) !important;
}

text tspan {
    fill: var(--bs-body-color);
    color: var(--bs-body-color);
    font-size: 16px !important;
    font-variant: all-small-caps;
    margin: 0 0 0 0;
    padding: 0 0 0 0;
}

.list-numbers {
    align-items: center;
    color: var(--bs-body-color);
    display: flex;
    justify-content: center;
    width: calc(100% - 2.15rem);
}

.list-numbers-trees {
    display: flex;
    justify-content: center;
}

.number-block {
    background: rgba(var(--bs-body-color-rgb), 0.03);
    border: var(--bs-border-width) solid var(--bs-border-color-translucent);
    height: 3rem;
    justify-content: center;
    margin: 1rem;
    padding: 1rem;
    width: 3rem;
}

.number-block[selected] {
    box-shadow: 0 0 1rem rgba(var(--bs-body-color-rgb), 0.375) !important;
}

/* Dark Mode */
i#themeIcon {
    color: white !important;
}

/* Columns */
.columns {
    display: flex;
    flex-direction: row;
    width: 100%;
}

.column {
    display: block;
    width: calc(50vw - 2.5rem);
}

.column:first-child {
    margin-right: 0.5rem;
}

.column:nth-child(2) {
    margin-left: 0.5rem;
}

/* Lecture Videos */

.video-container {
    align-content: center;
    display: flex;
    justify-content: center;
    width: fit-content;
    margin: 0 auto 0 auto;
}

.video-container iframe {
    aspect-ratio: 16 / 9;
    clip-path: inset(1px 1px);
    height: 720px !important;
    width: 1280px !important;
}

/* Admonition */
details, .admonition {
    background-color: rgb(var(--bs-secondary-bg-rgb), 0.55);
    border-color: var(--bs-border-color);
    border-radius: var(--bs-border-radius-xl);
    border-style: var(--bs-border-style);
    border-width: var(--bs-border-width);
    margin: 0.75rem auto;
    padding: 0.75rem;
    width: 75%;
}

.admonition {
    display: flex;
    flex-direction: column;
}

details > summary:before, .admonition-title:before {
    font-family: "bootstrap-icons";
    padding-right: 0.5rem;
}

details > summary, .admonition-title {
    font-weight: 550;
}

.admonition-title {
    margin: 0 !important;
}

details > summary + p, .admonition > p {
    margin-top: 0.25rem;
    margin-bottom: 0.25rem;
}

details > summary + p:last-of-type, .admonition > p:last-of-type {
    margin-bottom: 0 !important;
}

/* Admoniiton Colors */

details.note, div.note, details.info, div.details {
    background-color: var(--bs-warning-bg-subtle);
    border-color: var(--bs-warning-border-subtle);
}

details.note > summary:before, .note .admonition-title:before, details.info > summary:before, .info .admonition-title:before {
    color: var(--bs-warning-text-emphasis) !important;
}

.note .admonition-title, details.note > summary, .info .admonition-title, details.info > summary {
    color: var(--bs-warning-text-emphasis) !important;
}

details.important, div.important {
    background-color: var(--bs-danger-bg-subtle);
    border-color: var(--bs-danger-border-subtle);
}

details.important > summary:before, .important .admonition-title:before {
    color: var(--bs-danger-text-emphasis) !important;
}

.important .admonition-title, details.important > summary {
    color: var(--bs-danger-text-emphasis) !important;
}

details.hint, div.hint, details.tip, div.tip {
    background-color: var(--bs-info-bg-subtle);
    border-color: var(--bs-info-border-subtle);
}

details.hint > summary:before, .hint .admonition-title:before, details.tip > summary:before, .tip .admonition-title:before {
    color: var(--bs-info-text-emphasis) !important;
}

.hint .admonition-title, details.hint > summary, .tip .admonition-title, details.tip > summary {
    color: var(--bs-info-text-emphasis) !important;
}

/* Admonition Icons */
details.note > summary:before, .note .admonition-title:before, details.info > summary:before, .info .admonition-title:before, details.important > summary:before, .important .admonition-title:before {
    content: "\F336";
}

details.hint > summary:before, .hint .admonition-title:before, details.tip > summary:before, .tip .admonition-title:before {
    content: "\F468";
}

/* Admonition Collapse Icon */
details > summary {
    align-items: center;
    display: inline-flex;
    flex-direction: row;
    width: 100%;
}

details summary:after {
    content: "\F285";
    display: flex;
    font-family: bootstrap-icons;
    margin: 0 0 0 auto;
    text-align: right;
    transition: transform .35s ease;
    transform-origin: .5em 50%;
}

details[open] summary:after {
    transform: rotate(90deg) !important;
}